from pyramid.view import view_config
from pyramid.response import Response,FileResponse
import sass

from ppss_scss import routepath,sourcedir,workingfolder
import os
import logging
l = logging.getLogger(__name__)

class PPSSViews():
    
    def __init__(self,request):
        self.request = request
    

    def createCSSPath(self):
        pass

    def createSCSSPath(self):
        pass

    @view_config(route_name='ppss_scss_compile')
    def servescss(self):
        #print "serve scss!!!!"
        cu = self.request.current_route_url()
        path = self.request.current_route_path()
        fizzle = list(self.request.matchdict.get('fizzle'))
        filename = fizzle[-1]
        if filename[-4:].lower() != ".css":
            return Response("Invalid extension",status_code=404)
        returnfilepath = os.path.join( workingfolder, "/".join(fizzle) )
        
        if not os.path.isfile(returnfilepath ):
            fizzle[-1]=fizzle[-1][:-4] +".scss"
            l.debug("++++ '{fz}'".format(fz=fizzle) )
            #print "++++ '{fz}'".format(fz=fizzle)
            srcfname = os.path.join(sourcedir,*fizzle)
            l.info("+++SCSS compile src='{fn}'".format(fn=srcfname))
            #print "+++SCSS compile src='{fn}'".format(fn=srcfname)
            css = sass.compile_file( str(srcfname) )
            with open( returnfilepath,'w'  ) as outputfile:
                outputfile.write(css)
        else:
            l.debug("Serving {file} from cache".format(file=returnfilepath) )
        return FileResponse(
            returnfilepath,
            request=self.request,
            content_type='text/css'
        )

        fname = os.path.join(sourcedir,*fizzle)
        if os.path.isfile(fname):
            r = Response(content_type='application/csv')
            response.app_iter = exp.writeAll()
            response.headers['Content-Disposition'] = ("attachment; filename=export.csv")
            return response 
        return Response('ok')


sourcedir = 'scss/'
routepath = '/css'
workingfolder = '/tmp'
import logging,os, shutil
l = logging.getLogger(__name__)


def getAndCreateDir(settings,key,default,create=True):
    directory = settings.get(key,default)
    if create and not os.path.exists(directory):
        os.makedirs(directory)
    return directory

def clearDir(directory):
    for the_file in os.listdir(directory):
        file_path = os.path.join(directory, the_file)
        try:
            if os.path.isfile(file_path):
                os.unlink(file_path)
            elif os.path.isdir(file_path): shutil.rmtree(file_path)
        except Exception as e:
            print(e)

def includeme(config):
    global sourcedir,routepath,workingfolder
    settings = config.get_settings()
    #sourcedir = settings.get('ppss_scss.srcdir','scss/')
    #routepath = settings.get('ppss_scss.routepath','/css/*fizzle')
    #workingfolder = settings.get('ppss_scss.workingfolder','/tmp/css/')
    sourcedir = getAndCreateDir(settings,'ppss_scss.srcdir','scss/')
    routepath = getAndCreateDir(settings,'ppss_scss.routepath','/css/*fizzle',False)
    workingfolder = getAndCreateDir(settings,'ppss_scss.workingfolder','/tmp/css/')
    if settings.get('ppss_scss.delete_on_start','True') == "True":
        clearDir(workingfolder)
    l.info("ppss_scss.sorucedir={src} ppss_scss.routepath = {route}".format(src=sourcedir,route=routepath))
    config.add_route('ppss_scss_compile', routepath)
    config.scan()


from setuptools import setup,find_packages

setup(name='ppss_scss',
      version='0.3.1',
      description='simple scsscompiler for pyramid',
      author='pdepmcp',
      author_email='d.cariboni@pingpongstars.it',
      url='http://www.pingpongstars.it',
      #packages=['src/test1'],
      install_requires=['sass','pyramid>=1.5.7'],
      packages=find_packages()
     )


